aboutsummaryrefslogtreecommitdiff
path: root/id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java
diff options
context:
space:
mode:
Diffstat (limited to 'id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java')
-rw-r--r--id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java40
1 files changed, 31 insertions, 9 deletions
diff --git a/id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java b/id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java
index 9ee1ec606..512d571ab 100644
--- a/id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java
+++ b/id.server/src/at/gv/egovernment/moa/id/config/auth/OAAuthParameter.java
@@ -13,10 +13,15 @@ public class OAAuthParameter {
* public URL prefix of the online application
*/
private String publicURLPrefix;
+
/**
- * determines whether "ZMR-Zahl" is to be included in the authentication data
+ * key box Identifier (e.g. CertifiedKeyPair, SecureSignatureKeyPair)
+ */
+ private String keyBoxIdentifier;
+ /**
+ * determines whether "Stammzahl" is to be included in the authentication data
*/
- private boolean provideZMRZahl;
+ private boolean provideStammzahl;
/**
* determines whether AUTH block is to be included in the authentication data
*/
@@ -43,11 +48,11 @@ public class OAAuthParameter {
}
/**
- * Returns the provideZMRZahl.
+ * Returns the provideStammzahl.
* @return String
*/
- public boolean getProvideZMRZahl() {
- return provideZMRZahl;
+ public boolean getProvideStammzahl() {
+ return provideStammzahl;
}
/**
@@ -58,6 +63,14 @@ public class OAAuthParameter {
return publicURLPrefix;
}
+ /**
+ * Returns the key box identifier.
+ * @return String
+ */
+ public String getKeyBoxIdentifier() {
+ return keyBoxIdentifier;
+ }
+
/**
* Sets the provideAuthBlock.
* @param provideAuthBlock The provideAuthBlock to set
@@ -75,11 +88,11 @@ public class OAAuthParameter {
}
/**
* Sets the provideZMRZahl.
* @param provideZMRZahl The provideZMRZahl to set
*/
- public void setProvideZMRZahl(boolean provideZMRZahl) {
- this.provideZMRZahl = provideZMRZahl;
+ public void setProvideStammzahl(boolean provideStammzahl) {
+ this.provideStammzahl = provideStammzahl;
}
/**
@@ -90,4 +103,13 @@ public class OAAuthParameter {
this.publicURLPrefix = publicURLPrefix;
}
+ /**
+ * Sets the key box identifier.
+ * @param keyBoxIdentifier to set
+ */
+ public void setKeyBoxIdentier(String keyBoxIdentifier) {
+ this.keyBoxIdentifier = keyBoxIdentifier;
+ }
+
+
}
@@ -75,11 +88,11 @@ public class OAAuthParameter {
}
/**
- * Sets the provideZMRZahl.
- * @param provideZMRZahl The provideZMRZahl to set
+ * Sets the provideStammzahl.
+ * @param provideStammzahl The provideStammzahl to set
*/